################################################################
# vs.dashboardmanager
# (C) 2010, Veit Schiele & Andreas Jung
# Published under the GNU Public Licence V 2 (GPL 2)
################################################################


DEPENDENCIES = (
    'collective.portletpage',
)

PROJECTNAME = 'vs.dashboardmanager'

ADD_PERMISSIONS = {
    'DashboardManager': 'vs.dashboardmanager: Add DashboardManager',
}